require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.*"
import "android.speech.tts.TextToSpeech"
import "java.util.Locale"

activity.setTitle("عكس النصوص")

-- تهيئة محرك تحويل النص إلى كلام
tts = TextToSpeech(activity, TextToSpeech.OnInitListener {
  onInit = function(status)
    if status == TextToSpeech.SUCCESS then
      tts.setLanguage(Locale("ar"))
    end
  end
})

-- تصميم الواجهة
scrollView = ScrollView(activity)
layout = LinearLayout(activity)
layout.setOrientation(LinearLayout.VERTICAL)

editText = EditText(activity)
editText.setHint("أدخل النص لعكسه")

reversedTextView = TextView(activity)
reversedTextView.setText("سيظهر النص المعكوس هنا")

reverseButton = Button(activity)
reverseButton.setText("عكس النص")

copyButton = Button(activity)
copyButton.setText("نسخ النص")

shareButton = Button(activity)
shareButton.setText("مشاركة النص")

clearButton = Button(activity)
clearButton.setText("مسح النص")

pasteButton = Button(activity)
pasteButton.setText("لصق")

-- وظيفة النطق
function speak(text)
  tts.speak(text, TextToSpeech.QUEUE_FLUSH, nil, nil)
end

-- زر اللصق
pasteButton.setOnClickListener(View.OnClickListener {
  onClick = function(v)
    local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = clipboard.getPrimaryClip()
    if clip and clip.getItemCount() > 0 then
      local pasteData = clip.getItemAt(0).getText()
      if pasteData then
        editText.setText(pasteData)
        speak("تم اللصق")
      end
    end
  end
})

-- إضافة العناصر
layout.addView(editText)
layout.addView(pasteButton)
layout.addView(reverseButton)
layout.addView(reversedTextView)
layout.addView(copyButton)
layout.addView(shareButton)
layout.addView(clearButton)

scrollView.addView(layout)
activity.setContentView(scrollView)

-- دالة عكس النص
function reverseText(text)
  return string.reverse(text)
end

originalText = ""

-- زر عكس/إرجاع النص الأصلي
reverseButton.setOnClickListener(View.OnClickListener {
  onClick = function(v)
    local inputText = editText.getText().toString()
    if inputText == "" then
      speak("لوحة المفاتيح فارغة، الرجاء إدخال نص")
      return
    end

    if reverseButton.getText() == "عكس النص" then
      originalText = inputText
      local reversed = reverseText(inputText)
      editText.setText(reversed)
      reversedTextView.setText(reversed)
      reverseButton.setText("النص الأصلي")
      speak("تم عكس النص")
    else
      editText.setText(originalText)
      reversedTextView.setText("سيظهر النص المعكوس هنا")
      reverseButton.setText("عكس النص")
      speak("تم استرجاع النص الأصلي")
    end
  end
})

-- زر النسخ
copyButton.setOnClickListener(View.OnClickListener {
  onClick = function(v)
    local input = editText.getText().toString()
    if input == "" then
      speak("لا يوجد نص لنسخه")
      return
    end
    local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = ClipData.newPlainText("نص معكوس", input)
    clipboard.setPrimaryClip(clip)
    speak("تم نسخ النص")
  end
})

-- زر المشاركة
shareButton.setOnClickListener(View.OnClickListener {
  onClick = function(v)
    local input = editText.getText().toString()
    if input == "" then
      speak("لا يوجد نص للمشاركة")
      return
    end
    local intent = Intent(Intent.ACTION_SEND)
    intent.setType("text/plain")
    intent.putExtra(Intent.EXTRA_TEXT, input)
    activity.startActivity(Intent.createChooser(intent, "مشاركة النص"))
    speak("جارٍ مشاركة النص")
  end
})

-- زر المسح
clearButton.setOnClickListener(View.OnClickListener {
  onClick = function(v)
    local input = editText.getText().toString()
    if input == "" then
      speak("لا داعي، لوحة المفاتيح فارغة أصلاً")
      return
    end
    editText.setText("")
    reversedTextView.setText("سيظهر النص المعكوس هنا")
    reverseButton.setText("عكس النص")
    originalText = ""
    speak("تم مسح النص")
  end
})